@@ -11,16 +11,26 @@ log = logging.getLogger(__name__)
 
 JINJA_ENV = Environment(loader=PackageLoader("fhir_cli"), autoescape=select_autoescape())
 
-# CDMs
+# FHIR
 
-FHIR_ID = "fhir"
 FHIR_API_URL = os.environ.get("FHIR_API_URL", "http://localhost:8080/fhir")
-FHIR_COLUMN_NAME = FHIR_ID
+FHIR_COLUMN_NAME = "fhir"
+
+# OMOP
+
+OMOP_TEMPLATES = (
+    "01-OMOPCDM_postgresql_5.4_ddl.sql.j2",
+    "02-OMOPCDM_postgresql_5.4_primary_keys.sql.j2",
+    "03-vocabulary.sql.j2",
+    "04-OMOPCDM_postgresql_5.4_constraints.sql.j2",
+    "05-OMOPCDM_postgresql_5.4_indices.sql.j2",
+)
 
 # DBT
 
 DBT_SCHEMA = os.environ.get("DBT_SCHEMA", "dbt")
-FHIR_DBT_SCHEMA = f"{DBT_SCHEMA}_{FHIR_ID}"
+FHIR_DBT_SCHEMA = f"{DBT_SCHEMA}_fhir"
+OMOP_DBT_SCHEMA = f"{DBT_SCHEMA}_omop"
 DBT_MODELS_DIR = "models"
 DBT_META_TABLE = "_meta"
 INIT_DB_TEMPLATE = "init_db.sql.j2"
